<?php
namespace codeneric\phmm\base\includes {
  require_once ($GLOBALS["HACKLIB_ROOT"]);
  use \codeneric\phmm\base\includes\Permission;
  use \codeneric\phmm\base\includes\Error;
  use \codeneric\phmm\base\includes\ErrorSeverity;
  use \codeneric\phmm\Logger;
  require_once (plugin_dir_path(dirname(__FILE__))."includes/requires.php");
  class Phmm {
    protected $loader;
    protected $handler;
    public function __construct() {
      $this->load_dependencies();
      $this->set_locale();
      $this->define_admin_hooks();
      $this->define_public_hooks();
      $this->set_error_handler();
    }
    private function set_error_handler() {
      $callback = Error::class."::handle_error_case";
      \HH\invariant_callback_register($callback);
    }
    private function load_dependencies() {
      $this->loader = new Loader();
      $this->loader->add_action(
        "codeneric/phmm/check_user_permission",
        Permission::class,
        "current_user_can_access_client"
      );
      new \codeneric\phmm\elementor\Extension();
    }
    private function set_locale() {
      $plugin_i18n = new i18n();
      $this->loader->add_action(
        "plugins_loaded",
        $plugin_i18n,
        "load_plugin_textdomain"
      );
    }
    private function define_admin_hooks() {
      $plugin_admin = \codeneric\phmm\base\admin\Main::class;
      $ajax = \codeneric\phmm\base\admin\ajax\Endpoints::class;
      $frontendHandler = \codeneric\phmm\base\admin\FrontendHandler::class;
      $settings = \codeneric\phmm\base\admin\Settings::class;
      $wizard = \codeneric\phmm\base\admin\Installation_Wizard::class;
      $custom_pages = \codeneric\phmm\base\frontend\CustomPages::class;
      $config = \codeneric\phmm\Configuration::get();
      \codeneric\phmm\base\admin\Main::add_custom_image_sizes();
      $this->loader
        ->add_action("wp_ajax_phmm_star_photo", $ajax, "label_images");
      $this->loader->add_action(
        "wp_ajax_phmm_dismiss_notice",
        $ajax,
        "dismiss_admin_notice"
      );
      $this->loader
        ->add_action("wp_ajax_phmm_get_debug_info", $ajax, "get_debug_info");
      $this->loader
        ->add_action("wp_ajax_phmm_save_client", $ajax, "save_client");
      $this->loader
        ->add_action("wp_ajax_phmm_save_project", $ajax, "save_project");
      $this->loader
        ->add_action("wp_ajax_phmm_send_feedback", $ajax, "send_feedback");
      $this->loader
        ->add_action("wp_ajax_nopriv_phmm_star_photo", $ajax, "label_images");
      $this->loader->add_action(
        "wp_ajax_phmm_number_of_zip_parts",
        $ajax,
        "get_download_zip_parts"
      );
      $this->loader->add_action(
        "wp_ajax_nopriv_phmm_number_of_zip_parts",
        $ajax,
        "get_download_zip_parts"
      );
      $this->loader->add_action(
        "wp_ajax_phmm_fetch_images",
        $ajax,
        "fetch_gallery_images"
      );
      $this->loader->add_action(
        "wp_ajax_nopriv_phmm_fetch_images",
        $ajax,
        "fetch_gallery_images"
      );
      $this->loader
        ->add_action("wp_ajax_phmm_label_image", $ajax, "label_images");
      $this->loader
        ->add_action("wp_ajax_phmm_check_username", $ajax, "check_username");
      $this->loader->add_action(
        "wp_ajax_analytics_opt_in_allow",
        $ajax,
        "analytics_opt_in_allow"
      );
      $this->loader
        ->add_action("wp_ajax_phmm_check_email", $ajax, "check_email");
      $this->loader->add_action(
        "wp_ajax_phmm_get_interactions",
        $ajax,
        "get_interactions"
      );
      $this->loader->add_action(
        "wp_ajax_phmm_get_original_image_url",
        $ajax,
        "get_original_image_url"
      );
      $this->loader->add_action(
        "wp_ajax_nopriv_phmm_get_original_image_url",
        $ajax,
        "get_original_image_url"
      );
      $this->loader->add_action(
        "wp_ajax_codeneric_phmm_update_premium",
        $ajax,
        "update_premium"
      );
      $this->loader->add_action(
        "wp_ajax_codeneric_phmm_set_product_demo_finished",
        $ajax,
        "set_product_demo_finished"
      );
      $this->loader->add_action(
        "wp_ajax_phmm_save_install_wizard",
        $ajax,
        "save_install_wizard_settings"
      );
      $this->loader
        ->add_action("init", $plugin_admin, "register_client_post_type");
      $this->loader->add_action(
        "admin_head",
        $frontendHandler,
        "handle_analytics_enqueue"
      );
      $this->loader->add_action(
        "wp_enqueue_scripts",
        $frontendHandler,
        "handle_dc_enqueue"
      );
      $this->loader->add_action(
        "admin_enqueue_scripts",
        $frontendHandler,
        "handle_dc_enqueue"
      );
      $this->loader->add_action(
        "admin_init",
        $plugin_admin,
        "give_admin_access_if_applicable"
      );
      $this->loader->add_action("admin_init", $wizard, "installation_wizard");
      $this->loader->add_action(
        "admin_menu",
        $wizard,
        "add_installation_wizard_menu_page"
      );
      $this->loader
        ->add_action("clear_auth_cookie", $plugin_admin, "remove_cookies");
      $this->loader->add_action(
        "admin_init",
        $frontendHandler,
        "handle_placeholder_image_upload"
      );
      $this->loader
        ->add_action("init", $plugin_admin, "register_project_post_type");
      $this->loader->add_action(
        "admin_enqueue_scripts",
        $frontendHandler,
        "enqueue_styles"
      );
      $this->loader->add_action(
        "admin_enqueue_scripts",
        $frontendHandler,
        "enqueue_scripts"
      );
      $this->loader->add_action(
        "admin_menu",
        \codeneric\phmm\base\admin\InteractionsPage::class,
        "add_page"
      );
      $this->loader->add_action("admin_menu", $settings, "add_settings_page");
      $this->loader->add_action(
        "admin_menu",
        \codeneric\phmm\base\admin\SupportPage::class,
        "add_page"
      );
      $this->loader->add_action(
        "admin_menu",
        \codeneric\phmm\base\admin\PremiumPage::class,
        "add_page"
      );
      $this->loader->add_action(
        "admin_init",
        \codeneric\phmm\base\admin\InteractionsPage::class,
        "init"
      );
      $this->loader->add_action("admin_init", $settings, "init");
      $this->loader->add_action(
        "admin_init",
        \codeneric\phmm\base\admin\PremiumPage::class,
        "init"
      );
      $this->loader
        ->add_action("admin_init", $plugin_admin, "update_database");
      $this->loader->add_action(
        "admin_init",
        $plugin_admin,
        "plugin_deactivation_survey"
      );
      $this->loader
        ->add_action("admin_init", $plugin_admin, "remove_update_cache");
      $this->loader->add_action(
        "admin_init",
        $plugin_admin,
        "add_admin_notice_rate_the_plugin"
      );
      $this->loader->add_action(
        "admin_init",
        $plugin_admin,
        "add_admin_notice_analytics_opt_in"
      );
      $this->loader->add_action(
        "add_meta_boxes_".$config[\hacklib_id("client_post_type")],
        $plugin_admin,
        "add_client_meta_box"
      );
      $this->loader->add_action(
        "add_meta_boxes_".$config[\hacklib_id("project_post_type")],
        $plugin_admin,
        "add_project_meta_box"
      );
      $this->loader
        ->add_action("save_post", $plugin_admin, "save_meta_box_data", 10, 3);
      $this->loader
        ->add_action("after_setup_theme", $frontendHandler, "hide_admin_bar");
      $this->loader->add_action(
        "before_delete_post",
        $plugin_admin,
        "cleanup_before_deletion"
      );
      $this->loader->add_action(
        "admin_notices",
        $frontendHandler,
        "warn_if_page_template_not_exists"
      );
      $this->loader->add_filter(
        "enter_title_here",
        $frontendHandler,
        "change_title_placeholder"
      );
      $this->loader
        ->add_filter("upload_dir", $plugin_admin, "resume_photo_upload_dir");
      $this->loader->add_filter(
        "display_post_states",
        $custom_pages,
        "add_display_post_states",
        10,
        2
      );
      $this->loader->add_filter(
        "manage_".$config[\hacklib_id("client_post_type")]."_posts_columns",
        $frontendHandler,
        "define_client_table_columns"
      );
      $this->loader->add_action(
        "manage_".
        $config[\hacklib_id("client_post_type")].
        "_posts_custom_column",
        $frontendHandler,
        "fill_client_columns",
        10,
        2
      );
      $this->loader->add_filter(
        "manage_".$config[\hacklib_id("project_post_type")]."_posts_columns",
        $frontendHandler,
        "define_project_table_columns"
      );
      $this->loader->add_action(
        "manage_".
        $config[\hacklib_id("project_post_type")].
        "_posts_custom_column",
        $frontendHandler,
        "fill_project_columns",
        10,
        2
      );
      $this->loader->add_action(
        "post_type_link",
        $frontendHandler,
        "replace_permalinks",
        10,
        4
      );
      $this->loader->add_action(
        "init",
        \codeneric\phmm\base\includes\Labels::class,
        "initLabelStore",
        10
      );
      $this->loader
        ->add_action("template_redirect", $plugin_admin, "provide_csv");
      $this->loader->add_action(
        "codeneric/phmm/watermark",
        \codeneric\phmm\base\Watermarker::class,
        "watermark_image",
        10,
        1
      );
      $this->loader
        ->add_action("deleted_user", Client::class, "delete_client");
      $this->loader->add_action(
        "ajax_query_attachments_args",
        $plugin_admin,
        "mutate_media_library_query"
      );
      $this->loader->add_filter(
        "wp_privacy_personal_data_exporters",
        Privacy::class,
        "register_data_exporter"
      );
      $this->loader
        ->add_action("admin_init", Privacy::class, "get_privacy_content");
      $this->loader->add_action(
        "update_option_codeneric_phmm_plugin_settings",
        $plugin_admin,
        "plugin_settings_changed",
        10,
        2
      );
      $this->loader->add_filter(
        "next_post_link",
        $frontendHandler,
        "remove_post_links_for_custom_post_types"
      );
      $this->loader->add_filter(
        "previous_post_link",
        $frontendHandler,
        "remove_post_links_for_custom_post_types"
      );
      $this->loader->add_action(
        "delete_attachment",
        \codeneric\phmm\base\includes\Image::class,
        "delete_watermarked_versions",
        10,
        1
      );
      $this->loader->add_action(
        "add_meta_boxes",
        $plugin_admin,
        "remove_yoast_seo_meta",
        100
      );
    }
    private function define_public_hooks() {
      $plugin_public = \codeneric\phmm\base\frontend\Main::class;
      $custom_pages = \codeneric\phmm\base\frontend\CustomPages::class;
      $this->loader->add_filter("init", $plugin_public, "posts_logout");
      $this->loader
        ->add_action("template_redirect", $plugin_public, "handle_access");
      $this->loader
        ->add_action("wp_enqueue_scripts", $plugin_public, "enqueue_styles");
      $this->loader
        ->add_action("wp_enqueue_scripts", $plugin_public, "enqueue_scripts");
      $this->loader
        ->add_filter("the_content", $plugin_public, "the_content_hook");
      $this->loader
        ->add_filter("the_title", $custom_pages, "customize_title", 10, 2);
      $this->loader->add_filter(
        "get_post_metadata",
        $custom_pages,
        "customize_featured_image",
        10,
        3
      );
      $this->loader
        ->add_action("template_include", $plugin_public, "apply_template");
      if (\hacklib_cast_as_boolean(
            \codeneric\phmm\Utils::wp_version_is_at_least("4.7.0")
          )) {
        $this->loader->add_action(
          "post_password_required",
          $plugin_public,
          "filter_post_password_required",
          20,
          2
        );
      } else {
        $this->loader->add_filter(
          "the_password_form",
          $plugin_public,
          "the_password_form_hook"
        );
      }
      $this->loader->add_filter(
        "protected_title_format",
        $plugin_public,
        "remove_protected_string"
      );
      $this->loader->add_filter(
        "jetpack_photon_skip_image",
        $plugin_public,
        "photon_exceptions",
        10,
        3
      );
      $this->loader->add_filter(
        "wp_list_pages_excludes",
        $custom_pages,
        "exclude_intelligently_from_wp_list_pages",
        10,
        3
      );
      $this->loader->add_filter(
        "wp_get_nav_menu_items",
        $custom_pages,
        "exclude_intelligently_from_nav_menu_items",
        10,
        3
      );
      $this->loader->add_filter(
        "jetpack_photon_override_image_downsize",
        $plugin_public,
        "photon_exceptions_2",
        10,
        2
      );
      $this->loader->add_action(
        "template_redirect",
        $plugin_public,
        "provide_secured_image"
      );
      $this->loader->add_action(
        "template_redirect",
        $plugin_public,
        "redirect_from_portal_page"
      );
      $this->loader->add_action(
        "template_redirect",
        $plugin_public,
        "redirect_direct_gallery_page_visitor"
      );
      $this->loader
        ->add_action("wp_login_failed", $plugin_public, "login_failed");
      $this->loader->add_action(
        "get_template_part",
        $plugin_public,
        "try_to_handle_bad_theme",
        10,
        3
      );
      $this->loader->add_action(
        "get_footer",
        $plugin_public,
        "force_the_content",
        10,
        1
      );
      \add_shortcode(
        \codeneric\phmm\base\frontend\Shortcodes::GALLERY,
        array($plugin_public, "gallery_shortcode")
      );
      \add_shortcode(
        \codeneric\phmm\base\frontend\Shortcodes::CLIENT,
        array($plugin_public, "client_shortcode")
      );
      \add_shortcode(
        \codeneric\phmm\base\frontend\Shortcodes::PORTAL,
        array($plugin_public, "portal_shortcode")
      );
      \add_shortcode(
        \codeneric\phmm\base\frontend\Shortcodes::PORTFOLIO,
        array($plugin_public, "portfolio_shortcode")
      );
    }
    public function run() {
      $this->loader->run();
    }
    public function get_loader() {
      return $this->loader;
    }
  }
}
